#ifdef LOCAL
#include "../testlib.h"
#else
#include "testlib.h"
#endif

using ll = long long;
using namespace std;

const ll MOD = 1'000'000'000 + 7;
vector<string> expr;
ll value;

int get_differ(const string &x, const string &y) {
  if (x.size() != y.size()) {
    return -1;
  }
  int diff = 0;
  for (int i = 0; i < x.size(); i++) {
    if (x[i] != y[i]) diff++;
  }
  return diff;
}

vector<vector<ll>> get_mul_blocks(const vector<string> &es) {
  vector<vector<ll>> blocks = {{}};
  for (const string &token : es) {
    if (token == "+") {
      blocks.emplace_back();
    } else if (token == "*") {
      continue;
    } else {
      blocks.back().push_back(stoll(token));
    }
  }
  return blocks;
}

ll eval(const vector<vector<ll>> &blocks) {
  ll sum = 0;
  for (const vector<ll> &bl : blocks) {
    ll prod = 1;
    for (ll x : bl) {
      prod = (prod * x) % MOD;
    }
    sum += prod;
    if (sum >= MOD) sum -= MOD;
  }
  return sum;
}


// 0 - not found, 1 - found correct, -1 - found incorrect
int check_ans(InStream &in) {
  std::string verdict = in.readWord("YES|NO", "result");
  if (verdict == "NO") return 0;

  int k = in.readInt(0, 2, "k");
  int numbers_in_expr = expr.size() - expr.size() / 2;
  vector<string> think_was = expr;
  int total_change = 0;
  for (int i = 0; i < k; i++) {
    int pos = in.readInt(1, numbers_in_expr, "changed pos");
    pos = 2 * (pos - 1);

    ll old_val = in.readLong(0, MOD - 1, "old value");
    int diff = get_differ(expr[pos], to_string(old_val));
    if (diff < 0) {
      return -1;
    }
    total_change += diff;
    think_was[pos] = to_string(old_val);
  }
  if (total_change > 2) return -1;
  ll final_value = eval(get_mul_blocks(think_was));
  return final_value == value ? 1 : -1;
}

void readInput() {
  while (true) {
    string num = inf.readWord();
    expr.push_back(num);
    string op = inf.readWord();
    if (op != "=") {
      expr.push_back(op);
    } else {
      break;
    }
  }
  value = inf.readLong();
}

int main(int argc, char* argv[]) {
  registerTestlibCmd(argc, argv);

  readInput();

  int pans = check_ans(ouf);
  int jans = check_ans(ans);

  if (jans == -1 || (pans > jans)) {
    quitf(_fail, (jans == -1 ? "Jury failed"
                             : "Participant found answer, while jury didn't"));
  }
  if (jans != pans) {
    quitf(_wa, "Jury found answer, but participant didn't");
  } else {
    quitf(_ok, (jans == 0 ? "Answer not found" : "Found correct answer"));
  }
}