//  Nikita Golikov, 2023

#include <bits/stdc++.h>

using namespace std;

using uint = unsigned int;
using ll = long long;
using ull = unsigned long long;

#ifdef GOLIKOV
#define debug(x) cerr << (#x) << ":\t" << (x) << endl
#else
#define debug(x) 238;
#endif

template <class A, class B>
bool smin(A& x, B&& y) {
  if (y < x) {
    x = y;
    return true;
  }
  return false;
}

template <class A, class B>
bool smax(A& x, B&& y) {
  if (x < y) {
    x = y;
    return true;
  }
  return false;
}

int const MOD = int(1e9 + 7);

int add(int x, int y) {
  x += y;
  if (x >= MOD) x -= MOD;
  return x;
}

int sub(int x, int y) {
  x -= y;
  if (x < 0) x += MOD;
  return x;
}

int mul(ll x, int y) {
  return int(x * y % MOD);
}

int pw(int x, int d) {
  int r = 1;
  while (d) {
    if (d & 1) r = mul(r, x);
    x = mul(x, x);
    d /= 2;
  }
  return r;
}

int inv(int x) {
  return pw(x, MOD - 2);
}

#include <ext/pb_ds/assoc_container.hpp>
using namespace __gnu_pbds;

struct chash {
  static auto const C = (ull) 7e18 + 23;
  static_assert(C % 2);

  ull const RANDOM = chrono::steady_clock::now().time_since_epoch().count();
  ull const BASE =
      chrono::steady_clock::now().time_since_epoch().count();

  ull operator()(ull x) const {
    return __builtin_bswap64((x ^ RANDOM) * C);
  }

  template <class A, class B>
  ull operator()(pair<A, B> const& p) const {
    return (*this)(p.first) * BASE + (*this)(p.second);
  }

  template <class T, class = decltype(T().begin())>
  ull operator()(T const& x) const {
    ull res = 0;
    for (auto const& y : x) {
      res *= BASE;
      res += (*this)(y);
    }
    return res;
  }
};

template <class T> using hash_set = gp_hash_table<T, null_type, chash>;
template <class K, class V> using hash_map = gp_hash_table<K, V, chash>;

int main() {
#ifdef GOLIKOV
  assert(freopen("in", "rt", stdin));
  auto _clock_start = chrono::high_resolution_clock::now();
#endif
  ios::sync_with_stdio(false);
  cin.tie(nullptr);

  string tk;
  vector<vector<string>> input_strings;
  input_strings.emplace_back();
  vector<vector<int>> input;
  input.emplace_back();
  vector<vector<int>> positions;
  positions.emplace_back();
  int val;
  int curPos = 0;
  while (true) {
    cin >> tk;
    if (tk == "+") {
      input_strings.emplace_back();
      input.emplace_back();
      positions.emplace_back();
      continue;
    }
    if (tk == "*") {
      continue;
    }
    if (tk == "=") {
      cin >> val;
      break;
    }
    input_strings.back().push_back(tk);
    input.back().push_back(atoi(tk.c_str()));
    positions.back().push_back(curPos++);
  }
  int n = int(input_strings.size());
  int initVal = 0;
  for (int i = 0; i < n; ++i) {
    int prod = 1;
    for (int x : input[i]) {
      prod = mul(prod, x);
    }
    initVal = add(initVal, prod);
  }
  auto Len = [&](int i, int j) {
    return int(input_strings[i][j].size());
  };
  auto GetDigit = [&](int i, int j, int p) -> int {
    return input_strings[i][j][p] - '0';
  };
  auto ValidChange = [&](int i, int j, int p, int d) {
    int len = Len(i, j);
    //  leading zero
    if (p == 0 && d == 0) {
      return false;
    }
    if (len != 10) {
      return true;
    }
    return p == len - 1 && d < 7;
  };
  debug(initVal);
  if (initVal == val) {
    cout << "YES\n";
    cout << 0 << '\n';
    return 0;
  }
  vector<vector<int>> prefix_prods(n), suffix_prods(n);
  vector<int> powers(10);
  powers[0] = 1;
  for (int i = 1; i < 10; ++i) {
    powers[i] = mul(powers[i - 1], 10);
  }
  for (int i = 0; i < n; ++i) {
    int sz = int(input[i].size());
    prefix_prods[i].resize(sz + 1);
    suffix_prods[i].resize(sz + 1);
    prefix_prods[i][0] = 1;
    suffix_prods[i][sz] = 1;
    for (int j = 0; j < sz; ++j) {
      prefix_prods[i][j + 1] = mul(prefix_prods[i][j], input[i][j]);
      suffix_prods[i][sz - j - 1] = mul(suffix_prods[i][sz - j], input[i][sz - j - 1]);
    }
    for (int j = 0; j < sz; ++j) {
      int len = Len(i, j);
      for (int p = 0; p < len; ++p) {
        int here = GetDigit(i, j, p);
        for (int d = 0; d < 10; ++d) {
          if (!ValidChange(i, j, p, d)) {
            continue;
          }
          int newVal = sub(initVal, prefix_prods[i][sz]);
          int newValHere = add(input[i][j], mul(powers[len - p - 1], sub(d, here)));
          newVal = add(newVal, mul(prefix_prods[i][j], mul(suffix_prods[i][j + 1], newValHere)));
          if (newVal == val) {
            cout << "YES\n";
            cout << 1 << '\n';
            cout << positions[i][j] + 1 << ' ' << newValHere << '\n';
            return 0;
          }
        }
      }
    }
  }
  hash_map<int, pair<int, int>> addMap{};
  for (int i = 0; i < n; ++i) {
    int sz = int(input[i].size());
    for (int j = 0; j < sz; ++j) {
      int len = Len(i, j);
      for (int p = 0; p < len; ++p) {
        int here = GetDigit(i, j, p);
        for (int d = 0; d < 10; ++d) {
          if (!ValidChange(i, j, p, d)) {
            continue;
          }
          int dx = mul(powers[len - p - 1], sub(d, here));
          auto it = addMap.find(sub(val, add(initVal, dx)));
          if (it != addMap.end()) {
            int newValHere = add(input[i][j], mul(powers[len - p - 1], sub(d, here)));
            cout << "YES\n";
            cout << 2 << '\n';
            cout << it->second.first + 1 << ' ' << it->second.second << '\n';
            cout << positions[i][j] + 1 << ' ' << newValHere << '\n';
            return 0;
          }
        }
      }
    }
    for (int j = 0; j < sz; ++j) {
      int len = Len(i, j);
      for (int p = 0; p < len; ++p) {
        int here = GetDigit(i, j, p);
        for (int d = 0; d < 10; ++d) {
          if (!ValidChange(i, j, p, d)) {
            continue;
          }
          int dx = mul(powers[len - p - 1], sub(d, here));
          int newValHere = add(input[i][j], mul(powers[len - p - 1], sub(d, here)));
          addMap[dx] = make_pair(positions[i][j], newValHere);
        }
      }
    }
  }

  cout << "NO\n";

#ifdef GOLIKOV
  cerr << "Executed in " << chrono::duration_cast<chrono::milliseconds>(
                                chrono::high_resolution_clock::now()
                                - _clock_start).count() << "ms." << endl;
#endif
  return 0;
}